@@ -1,3 +1,5 @@
+# SPDX-License-Identifier: GPL-2.0-or-later
+
 """
 Keyboards class
 """
@@ -486,10 +488,12 @@ class RazerHuntsmanV2(_RippleKeyboard):
     USB_PID = 0x026C
     HAS_MATRIX = True
     MATRIX_DIMS = [6, 22]
+    POLL_RATES = [125, 250, 500, 1000, 2000, 4000, 8000]
     METHODS = ['get_device_type_keyboard', 'set_wave_effect', 'set_static_effect', 'set_spectrum_effect',
                'set_reactive_effect', 'set_none_effect', 'set_breath_random_effect', 'set_breath_single_effect', 'set_breath_dual_effect',
                'set_custom_effect', 'set_key_row', 'get_game_mode', 'set_game_mode', 'get_macro_mode', 'set_macro_mode',
                'get_macro_effect', 'set_macro_effect', 'get_macros', 'delete_macro', 'add_macro',
+               'get_poll_rate', 'set_poll_rate', 'get_supported_poll_rates', 'get_keyswitch_optimization', 'set_keyswitch_optimization',
                'set_starlight_random_effect', 'set_starlight_single_effect', 'set_starlight_dual_effect',
                'set_ripple_effect', 'set_ripple_effect_random_colour']
 
@@ -515,6 +519,25 @@ class RazerHuntsmanV2Analog(_RazerDeviceBrightnessSuspend):
     DEVICE_IMAGE = "https://dl.razerzone.com/src/4023-1-EN-v1.png"
 
 
+# TODO Should become _RippleKeyboard once kernel support for driver mode is implemented
+class RazerHuntsmanMiniAnalog(_RazerDeviceBrightnessSuspend):
+    """
+    Class for the Razer Huntsman Mini Analog
+    """
+    EVENT_FILE_REGEX = re.compile(r'.*Razer_Huntsman_Mini_Analog(-if01)?-event-kbd')
+
+    USB_VID = 0x1532
+    USB_PID = 0x0282
+    HAS_MATRIX = True
+    MATRIX_DIMS = [5, 15]
+    # TODO Remove get_keyboard_layout once not _RazerDeviceBrightnessSuspend anymore
+    METHODS = ['get_device_type_keyboard', 'set_wave_effect', 'set_static_effect', 'set_spectrum_effect',
+               'set_reactive_effect', 'set_none_effect', 'set_breath_random_effect', 'set_breath_single_effect', 'set_breath_dual_effect',
+               'set_custom_effect', 'set_key_row', 'get_keyboard_layout']
+
+    DEVICE_IMAGE = "https://assets.razerzone.com/eeimages/support/products/1689/1689-huntsmanmini.png"
+
+
 class RazerBlackWidowXTournamentEditionChroma(_RippleKeyboard):
     """
     Class for the Razer BlackWidow X Tournament Edition Chroma
