@@ -1,15 +1,9 @@
+/* SPDX-License-Identifier: GPL-2.0-or-later */
 /*
  * Copyright (c) 2015 Tim Theede <pez2001@voyagerproject.de>
  *               2015 Terry Cain <terrys-home.co.uk>
  */
 
-/*
- * This program is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by the Free
- * Software Foundation; either version 2 of the License, or (at your option)
- * any later version.
- */
-
 #ifndef __HID_RAZER_KBD_H
 #define __HID_RAZER_KBD_H
 
@@ -89,6 +83,7 @@
 #define USB_DEVICE_ID_RAZER_BLACKWIDOW_V3_MINI_WIRELESS 0x0271
 #define USB_DEVICE_ID_RAZER_BLADE_15_ADV_MID_2021 0x0276
 #define USB_DEVICE_ID_RAZER_BLADE_17_PRO_MID_2021 0x0279
+#define USB_DEVICE_ID_RAZER_HUNTSMAN_MINI_ANALOG 0x0282
 #define USB_DEVICE_ID_RAZER_BLADE_15_ADV_EARLY_2022 0x028A
 #define USB_DEVICE_ID_RAZER_BLADE_17_2022 0x028B
 #define USB_DEVICE_ID_RAZER_BLACKWIDOW_V3_TK 0x0A24
@@ -142,11 +137,7 @@
 
 
 struct razer_kbd_device {
-    struct usb_device *usbdev;
-    struct hid_device *hiddev;
     unsigned int fn_on;
-    char name[128];
-    char phys[64];
     DECLARE_BITMAP(pressed_fn, KEY_CNT);
 
     unsigned char block_keys[3];
