@@ -17,6 +17,7 @@ declare -A files_metadata=(
     ["charging_matrix_effect_static"]="w;"
     ["charging_matrix_effect_wave"]="w;"
     ["device_idle_time"]="rw;600"
+    ["device_mode"]="rw;0x0000"
     ["device_serial"]="r;XX0000000000" # default value will get overwritten
     ["device_type"]="r;%(name)s"
     ["dpi"]="rw;800:800"
@@ -35,8 +36,12 @@ declare -A files_metadata=(
     ["fully_charged_matrix_effect_static"]="w;"
     ["fully_charged_matrix_effect_wave"]="w;"
     ["game_led_state"]="rw;0"
+    ["keyswitch_optimization"]="rw;0"
     ["is_mug_present"]="r;0"
     ["kbd_layout"]="r;01"
+    ["key_alt_f4"]="rw;0x00"
+    ["key_alt_tab"]="rw;0x00"
+    ["key_super"]="rw;0x00"
     ["left_led_brightness"]="rw;0"
     ["left_matrix_effect_breath"]="w;"
     ["left_matrix_effect_none"]="w;"
@@ -192,8 +197,7 @@ EOF
         # "": sometimes we get empty line in here
         # "test": not used by daemon
         # "fn_toggle": not used by daemon
-        # "device_mode": daemon writes binary and reads ascii which can't be handled easily
-        [[ "$attr" = "" || "$attr" = "test" || "$attr" = "fn_toggle" || "$attr" = "device_mode" ]] && continue
+        [[ "$attr" = "" || "$attr" = "test" || "$attr" = "fn_toggle" ]] && continue
 
         metadata="${files_metadata[$attr]}"
         if [ -z "$metadata" ]; then
